# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/instance_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.api import operation_pb2 as yandex_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1 import instance_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/compute/v1/instance_service.proto',
  package='yandex.cloud.compute.v1',
  syntax='proto3',
  serialized_pb=_b('\n.yandex/cloud/compute/v1/instance_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1ayandex/api/operation.proto\x1a&yandex/cloud/compute/v1/instance.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"l\n\x12GetInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x33\n\x04view\x18\x02 \x01(\x0e\x32%.yandex.cloud.compute.v1.InstanceView\"\x91\x01\n\x14ListInstancesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"f\n\x15ListInstancesResponse\x12\x34\n\tinstances\x18\x01 \x03(\x0b\x32!.yandex.cloud.compute.v1.Instance\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xfd\x06\n\x15\x43reateInstanceRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8b\x01\n\x06labels\x18\x04 \x03(\x0b\x32:.yandex.cloud.compute.v1.CreateInstanceRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12\x1d\n\x07zone_id\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12(\n\x0bplatform_id\x18\x06 \x01(\tB\x13\xe8\xc7\x31\x01\xf2\xc7\x31\x0bstandard-v1\x12\x44\n\x0eresources_spec\x18\x07 \x01(\x0b\x32&.yandex.cloud.compute.v1.ResourcesSpecB\x04\xe8\xc7\x31\x01\x12N\n\x08metadata\x18\x08 \x03(\x0b\x32<.yandex.cloud.compute.v1.CreateInstanceRequest.MetadataEntry\x12G\n\x0e\x62oot_disk_spec\x18\t \x01(\x0b\x32).yandex.cloud.compute.v1.AttachedDiskSpecB\x04\xe8\xc7\x31\x01\x12P\n\x14secondary_disk_specs\x18\n \x03(\x0b\x32).yandex.cloud.compute.v1.AttachedDiskSpecB\x07\x82\xc8\x31\x03<=3\x12U\n\x17network_interface_specs\x18\x0b \x03(\x0b\x32-.yandex.cloud.compute.v1.NetworkInterfaceSpecB\x05\x82\xc8\x31\x01\x31\x12\x33\n\x08hostname\x18\x0c \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"7\n\x16\x43reateInstanceMetadata\x12\x1d\n\x0binstance_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\xe0\x04\n\x15UpdateInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8b\x01\n\x06labels\x18\x05 \x03(\x0b\x32:.yandex.cloud.compute.v1.UpdateInstanceRequest.LabelsEntryB?\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0b[-_0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x12\x12\x10[a-z][-_0-9a-z]*\x12$\n\x0bplatform_id\x18\x06 \x01(\tB\x0f\xf2\xc7\x31\x0bstandard-v1\x12>\n\x0eresources_spec\x18\x07 \x01(\x0b\x32&.yandex.cloud.compute.v1.ResourcesSpec\x12N\n\x08metadata\x18\x08 \x03(\x0b\x32<.yandex.cloud.compute.v1.UpdateInstanceRequest.MetadataEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16UpdateInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\":\n\x15\x44\x65leteInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x16\x44\x65leteInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"G\n\"GetInstanceSerialPortOutputRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"7\n#GetInstanceSerialPortOutputResponse\x12\x10\n\x08\x63ontents\x18\x01 \x01(\t\"8\n\x13StopInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x14StopInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"9\n\x14StartInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\",\n\x15StartInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\";\n\x16RestartInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\".\n\x17RestartInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"\x8b\x01\n\x19\x41ttachInstanceDiskRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12K\n\x12\x61ttached_disk_spec\x18\x02 \x01(\x0b\x32).yandex.cloud.compute.v1.AttachedDiskSpecB\x04\xe8\xc7\x31\x01\"B\n\x1a\x41ttachInstanceDiskMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x0f\n\x07\x64isk_id\x18\x02 \x01(\t\"\x9a\x01\n\x19\x44\x65tachInstanceDiskRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\x07\x64isk_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12/\n\x0b\x64\x65vice_name\x18\x03 \x01(\tB\x18\xf2\xc7\x31\x14[a-z][a-z0-9-_]{,19}H\x00\x42\x0c\n\x04\x64isk\x12\x04\xc0\xc1\x31\x01\"B\n\x1a\x44\x65tachInstanceDiskMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x0f\n\x07\x64isk_id\x18\x02 \x01(\t\"\x80\x01\n\x1dListInstanceOperationsRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"p\n\x1eListInstanceOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"w\n\rResourcesSpec\x12%\n\x06memory\x18\x01 \x01(\x03\x42\x15\xe8\xc7\x31\x01\xfa\xc7\x31\r<=34359738368\x12\x1b\n\x05\x63ores\x18\x02 \x01(\x03\x42\x0c\xe8\xc7\x31\x01\xfa\xc7\x31\x04<=32\x12\"\n\rcore_fraction\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30,5,100\"\xb4\x04\n\x10\x41ttachedDiskSpec\x12<\n\x04mode\x18\x01 \x01(\x0e\x32..yandex.cloud.compute.v1.AttachedDiskSpec.Mode\x12-\n\x0b\x64\x65vice_name\x18\x02 \x01(\tB\x18\xf2\xc7\x31\x14[a-z][a-z0-9-_]{,19}\x12\x13\n\x0b\x61uto_delete\x18\x03 \x01(\x08\x12G\n\tdisk_spec\x18\x04 \x01(\x0b\x32\x32.yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpecH\x00\x12\x1b\n\x07\x64isk_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x1a\xec\x01\n\x08\x44iskSpec\x12/\n\x04name\x18\x01 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x19\n\x07type_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12+\n\x04size\x18\x04 \x01(\x03\x42\x1d\xe8\xc7\x31\x01\xfa\xc7\x31\x15\x34\x31\x39\x34\x33\x30\x34-4398046511104\x12\x1c\n\x08image_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1f\n\x0bsnapshot_id\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x42\x08\n\x06source\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\r\n\tREAD_ONLY\x10\x01\x12\x0e\n\nREAD_WRITE\x10\x02\x42\x0c\n\x04\x64isk\x12\x04\xc0\xc1\x31\x01\"\xd3\x01\n\x14NetworkInterfaceSpec\x12\x1f\n\tsubnet_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12L\n\x17primary_v4_address_spec\x18\x02 \x01(\x0b\x32+.yandex.cloud.compute.v1.PrimaryAddressSpec\x12L\n\x17primary_v6_address_spec\x18\x03 \x01(\x0b\x32+.yandex.cloud.compute.v1.PrimaryAddressSpec\"l\n\x12PrimaryAddressSpec\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x45\n\x13one_to_one_nat_spec\x18\x02 \x01(\x0b\x32(.yandex.cloud.compute.v1.OneToOneNatSpec\"O\n\x0fOneToOneNatSpec\x12<\n\nip_version\x18\x01 \x01(\x0e\x32\".yandex.cloud.compute.v1.IpVersionB\x04\xe8\xc7\x31\x01*#\n\x0cInstanceView\x12\t\n\x05\x42\x41SIC\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x32\x9f\x11\n\x0fInstanceService\x12\x82\x01\n\x03Get\x12+.yandex.cloud.compute.v1.GetInstanceRequest\x1a!.yandex.cloud.compute.v1.Instance\"+\x82\xd3\xe4\x93\x02%\x12#/compute/v1/instances/{instance_id}\x12\x84\x01\n\x04List\x12-.yandex.cloud.compute.v1.ListInstancesRequest\x1a..yandex.cloud.compute.v1.ListInstancesResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/compute/v1/instances\x12\xa3\x01\n\x06\x43reate\x12..yandex.cloud.compute.v1.CreateInstanceRequest\x1a!.yandex.cloud.operation.Operation\"F\x82\xd3\xe4\x93\x02\x1a\"\x15/compute/v1/instances:\x01*\xb2\xd2*\"\n\x16\x43reateInstanceMetadata\x12\x08Instance\x12\xb1\x01\n\x06Update\x12..yandex.cloud.compute.v1.UpdateInstanceRequest\x1a!.yandex.cloud.operation.Operation\"T\x82\xd3\xe4\x93\x02(2#/compute/v1/instances/{instance_id}:\x01*\xb2\xd2*\"\n\x16UpdateInstanceMetadata\x12\x08Instance\x12\xbb\x01\n\x06\x44\x65lete\x12..yandex.cloud.compute.v1.DeleteInstanceRequest\x1a!.yandex.cloud.operation.Operation\"^\x82\xd3\xe4\x93\x02%*#/compute/v1/instances/{instance_id}\xb2\xd2*/\n\x16\x44\x65leteInstanceMetadata\x12\x15google.protobuf.Empty\x12\xce\x01\n\x13GetSerialPortOutput\x12;.yandex.cloud.compute.v1.GetInstanceSerialPortOutputRequest\x1a<.yandex.cloud.compute.v1.GetInstanceSerialPortOutputResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/compute/v1/instances/{instance_id}:serialPortOutput\x12\xba\x01\n\x04Stop\x12,.yandex.cloud.compute.v1.StopInstanceRequest\x1a!.yandex.cloud.operation.Operation\"a\x82\xd3\xe4\x93\x02*\"(/compute/v1/instances/{instance_id}:stop\xb2\xd2*-\n\x14StopInstanceMetadata\x12\x15google.protobuf.Empty\x12\xbe\x01\n\x05Start\x12-.yandex.cloud.compute.v1.StartInstanceRequest\x1a!.yandex.cloud.operation.Operation\"c\x82\xd3\xe4\x93\x02+\")/compute/v1/instances/{instance_id}:start\xb2\xd2*.\n\x15StartInstanceMetadata\x12\x15google.protobuf.Empty\x12\xc6\x01\n\x07Restart\x12/.yandex.cloud.compute.v1.RestartInstanceRequest\x1a!.yandex.cloud.operation.Operation\"g\x82\xd3\xe4\x93\x02-\"+/compute/v1/instances/{instance_id}:restart\xb2\xd2*0\n\x17RestartInstanceMetadata\x12\x15google.protobuf.Empty\x12\xc8\x01\n\nAttachDisk\x12\x32.yandex.cloud.compute.v1.AttachInstanceDiskRequest\x1a!.yandex.cloud.operation.Operation\"c\x82\xd3\xe4\x93\x02\x33\"./compute/v1/instances/{instance_id}:attachDisk:\x01*\xb2\xd2*&\n\x1a\x41ttachInstanceDiskMetadata\x12\x08Instance\x12\xc8\x01\n\nDetachDisk\x12\x32.yandex.cloud.compute.v1.DetachInstanceDiskRequest\x1a!.yandex.cloud.operation.Operation\"c\x82\xd3\xe4\x93\x02\x33\"./compute/v1/instances/{instance_id}:detachDisk:\x01*\xb2\xd2*&\n\x1a\x44\x65tachInstanceDiskMetadata\x12\x08Instance\x12\xb9\x01\n\x0eListOperations\x12\x36.yandex.cloud.compute.v1.ListInstanceOperationsRequest\x1a\x37.yandex.cloud.compute.v1.ListInstanceOperationsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./compute/v1/instances/{instance_id}/operationsBEZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])

_INSTANCEVIEW = _descriptor.EnumDescriptor(
  name='InstanceView',
  full_name='yandex.cloud.compute.v1.InstanceView',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BASIC', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FULL', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4578,
  serialized_end=4613,
)
_sym_db.RegisterEnumDescriptor(_INSTANCEVIEW)

InstanceView = enum_type_wrapper.EnumTypeWrapper(_INSTANCEVIEW)
BASIC = 0
FULL = 1


_ATTACHEDDISKSPEC_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='yandex.cloud.compute.v1.AttachedDiskSpec.Mode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODE_UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READ_ONLY', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READ_WRITE', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4098,
  serialized_end=4157,
)
_sym_db.RegisterEnumDescriptor(_ATTACHEDDISKSPEC_MODE)


_GETINSTANCEREQUEST = _descriptor.Descriptor(
  name='GetInstanceRequest',
  full_name='yandex.cloud.compute.v1.GetInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.GetInstanceRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view', full_name='yandex.cloud.compute.v1.GetInstanceRequest.view', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=278,
  serialized_end=386,
)


_LISTINSTANCESREQUEST = _descriptor.Descriptor(
  name='ListInstancesRequest',
  full_name='yandex.cloud.compute.v1.ListInstancesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.ListInstancesRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListInstancesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\372\3071\006<=1000')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListInstancesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\005<=100')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.compute.v1.ListInstancesRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\006<=1000')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=389,
  serialized_end=534,
)


_LISTINSTANCESRESPONSE = _descriptor.Descriptor(
  name='ListInstancesResponse',
  full_name='yandex.cloud.compute.v1.ListInstancesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instances', full_name='yandex.cloud.compute.v1.ListInstancesResponse.instances', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListInstancesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=536,
  serialized_end=638,
)


_CREATEINSTANCEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.CreateInstanceRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1440,
  serialized_end=1485,
)

_CREATEINSTANCEREQUEST_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='yandex.cloud.compute.v1.CreateInstanceRequest.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1487,
  serialized_end=1534,
)

_CREATEINSTANCEREQUEST = _descriptor.Descriptor(
  name='CreateInstanceRequest',
  full_name='yandex.cloud.compute.v1.CreateInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\005<=256')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.zone_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='platform_id', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.platform_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\362\3071\013standard-v1')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources_spec', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.resources_spec', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.metadata', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='boot_disk_spec', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.boot_disk_spec', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secondary_disk_specs', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.secondary_disk_specs', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\202\3101\003<=3')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='network_interface_specs', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.network_interface_specs', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\202\3101\0011')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.hostname', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CREATEINSTANCEREQUEST_LABELSENTRY, _CREATEINSTANCEREQUEST_METADATAENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=641,
  serialized_end=1534,
)


_CREATEINSTANCEMETADATA = _descriptor.Descriptor(
  name='CreateInstanceMetadata',
  full_name='yandex.cloud.compute.v1.CreateInstanceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.CreateInstanceMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\004<=50')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1536,
  serialized_end=1591,
)


_UPDATEINSTANCEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1440,
  serialized_end=1485,
)

_UPDATEINSTANCEREQUEST_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1487,
  serialized_end=1534,
)

_UPDATEINSTANCEREQUEST = _descriptor.Descriptor(
  name='UpdateInstanceRequest',
  full_name='yandex.cloud.compute.v1.UpdateInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\005<=256')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='platform_id', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.platform_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\3071\013standard-v1')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resources_spec', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.resources_spec', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.metadata', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEINSTANCEREQUEST_LABELSENTRY, _UPDATEINSTANCEREQUEST_METADATAENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1594,
  serialized_end=2202,
)


_UPDATEINSTANCEMETADATA = _descriptor.Descriptor(
  name='UpdateInstanceMetadata',
  full_name='yandex.cloud.compute.v1.UpdateInstanceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.UpdateInstanceMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2204,
  serialized_end=2249,
)


_DELETEINSTANCEREQUEST = _descriptor.Descriptor(
  name='DeleteInstanceRequest',
  full_name='yandex.cloud.compute.v1.DeleteInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.DeleteInstanceRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2251,
  serialized_end=2309,
)


_DELETEINSTANCEMETADATA = _descriptor.Descriptor(
  name='DeleteInstanceMetadata',
  full_name='yandex.cloud.compute.v1.DeleteInstanceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.DeleteInstanceMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2311,
  serialized_end=2356,
)


_GETINSTANCESERIALPORTOUTPUTREQUEST = _descriptor.Descriptor(
  name='GetInstanceSerialPortOutputRequest',
  full_name='yandex.cloud.compute.v1.GetInstanceSerialPortOutputRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.GetInstanceSerialPortOutputRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2358,
  serialized_end=2429,
)


_GETINSTANCESERIALPORTOUTPUTRESPONSE = _descriptor.Descriptor(
  name='GetInstanceSerialPortOutputResponse',
  full_name='yandex.cloud.compute.v1.GetInstanceSerialPortOutputResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='contents', full_name='yandex.cloud.compute.v1.GetInstanceSerialPortOutputResponse.contents', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2431,
  serialized_end=2486,
)


_STOPINSTANCEREQUEST = _descriptor.Descriptor(
  name='StopInstanceRequest',
  full_name='yandex.cloud.compute.v1.StopInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.StopInstanceRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2488,
  serialized_end=2544,
)


_STOPINSTANCEMETADATA = _descriptor.Descriptor(
  name='StopInstanceMetadata',
  full_name='yandex.cloud.compute.v1.StopInstanceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.StopInstanceMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2546,
  serialized_end=2589,
)


_STARTINSTANCEREQUEST = _descriptor.Descriptor(
  name='StartInstanceRequest',
  full_name='yandex.cloud.compute.v1.StartInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.StartInstanceRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2591,
  serialized_end=2648,
)


_STARTINSTANCEMETADATA = _descriptor.Descriptor(
  name='StartInstanceMetadata',
  full_name='yandex.cloud.compute.v1.StartInstanceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.StartInstanceMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2650,
  serialized_end=2694,
)


_RESTARTINSTANCEREQUEST = _descriptor.Descriptor(
  name='RestartInstanceRequest',
  full_name='yandex.cloud.compute.v1.RestartInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.RestartInstanceRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2696,
  serialized_end=2755,
)


_RESTARTINSTANCEMETADATA = _descriptor.Descriptor(
  name='RestartInstanceMetadata',
  full_name='yandex.cloud.compute.v1.RestartInstanceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.RestartInstanceMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2757,
  serialized_end=2803,
)


_ATTACHINSTANCEDISKREQUEST = _descriptor.Descriptor(
  name='AttachInstanceDiskRequest',
  full_name='yandex.cloud.compute.v1.AttachInstanceDiskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.AttachInstanceDiskRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attached_disk_spec', full_name='yandex.cloud.compute.v1.AttachInstanceDiskRequest.attached_disk_spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2806,
  serialized_end=2945,
)


_ATTACHINSTANCEDISKMETADATA = _descriptor.Descriptor(
  name='AttachInstanceDiskMetadata',
  full_name='yandex.cloud.compute.v1.AttachInstanceDiskMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.AttachInstanceDiskMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.AttachInstanceDiskMetadata.disk_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2947,
  serialized_end=3013,
)


_DETACHINSTANCEDISKREQUEST = _descriptor.Descriptor(
  name='DetachInstanceDiskRequest',
  full_name='yandex.cloud.compute.v1.DetachInstanceDiskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.DetachInstanceDiskRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.DetachInstanceDiskRequest.disk_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\004<=50')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='yandex.cloud.compute.v1.DetachInstanceDiskRequest.device_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\3071\024[a-z][a-z0-9-_]{,19}')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='disk', full_name='yandex.cloud.compute.v1.DetachInstanceDiskRequest.disk',
      index=0, containing_type=None, fields=[], options=_descriptor._ParseOptions(descriptor_pb2.OneofOptions(), _b('\300\3011\001'))),
  ],
  serialized_start=3016,
  serialized_end=3170,
)


_DETACHINSTANCEDISKMETADATA = _descriptor.Descriptor(
  name='DetachInstanceDiskMetadata',
  full_name='yandex.cloud.compute.v1.DetachInstanceDiskMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.DetachInstanceDiskMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.DetachInstanceDiskMetadata.disk_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3172,
  serialized_end=3238,
)


_LISTINSTANCEOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListInstanceOperationsRequest',
  full_name='yandex.cloud.compute.v1.ListInstanceOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.ListInstanceOperationsRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListInstanceOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\372\3071\006<=1000')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListInstanceOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\005<=100')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3241,
  serialized_end=3369,
)


_LISTINSTANCEOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListInstanceOperationsResponse',
  full_name='yandex.cloud.compute.v1.ListInstanceOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.compute.v1.ListInstanceOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListInstanceOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3371,
  serialized_end=3483,
)


_RESOURCESSPEC = _descriptor.Descriptor(
  name='ResourcesSpec',
  full_name='yandex.cloud.compute.v1.ResourcesSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='memory', full_name='yandex.cloud.compute.v1.ResourcesSpec.memory', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\372\3071\r<=34359738368')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cores', full_name='yandex.cloud.compute.v1.ResourcesSpec.cores', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\372\3071\004<=32')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='core_fraction', full_name='yandex.cloud.compute.v1.ResourcesSpec.core_fraction', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\372\3071\0070,5,100')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3485,
  serialized_end=3604,
)


_ATTACHEDDISKSPEC_DISKSPEC = _descriptor.Descriptor(
  name='DiskSpec',
  full_name='yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpec.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpec.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\005<=256')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_id', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpec.type_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\004<=50')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpec.size', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\372\3071\0254194304-4398046511104')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_id', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpec.image_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\004<=50')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='snapshot_id', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpec.snapshot_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\004<=50')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpec.source',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3860,
  serialized_end=4096,
)

_ATTACHEDDISKSPEC = _descriptor.Descriptor(
  name='AttachedDiskSpec',
  full_name='yandex.cloud.compute.v1.AttachedDiskSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.device_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\3071\024[a-z][a-z0-9-_]{,19}')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auto_delete', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.auto_delete', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disk_spec', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.disk_spec', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.disk_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\004<=50')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ATTACHEDDISKSPEC_DISKSPEC, ],
  enum_types=[
    _ATTACHEDDISKSPEC_MODE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='disk', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.disk',
      index=0, containing_type=None, fields=[], options=_descriptor._ParseOptions(descriptor_pb2.OneofOptions(), _b('\300\3011\001'))),
  ],
  serialized_start=3607,
  serialized_end=4171,
)


_NETWORKINTERFACESPEC = _descriptor.Descriptor(
  name='NetworkInterfaceSpec',
  full_name='yandex.cloud.compute.v1.NetworkInterfaceSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.compute.v1.NetworkInterfaceSpec.subnet_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='primary_v4_address_spec', full_name='yandex.cloud.compute.v1.NetworkInterfaceSpec.primary_v4_address_spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='primary_v6_address_spec', full_name='yandex.cloud.compute.v1.NetworkInterfaceSpec.primary_v6_address_spec', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4174,
  serialized_end=4385,
)


_PRIMARYADDRESSSPEC = _descriptor.Descriptor(
  name='PrimaryAddressSpec',
  full_name='yandex.cloud.compute.v1.PrimaryAddressSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='yandex.cloud.compute.v1.PrimaryAddressSpec.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='one_to_one_nat_spec', full_name='yandex.cloud.compute.v1.PrimaryAddressSpec.one_to_one_nat_spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4387,
  serialized_end=4495,
)


_ONETOONENATSPEC = _descriptor.Descriptor(
  name='OneToOneNatSpec',
  full_name='yandex.cloud.compute.v1.OneToOneNatSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip_version', full_name='yandex.cloud.compute.v1.OneToOneNatSpec.ip_version', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4497,
  serialized_end=4576,
)

_GETINSTANCEREQUEST.fields_by_name['view'].enum_type = _INSTANCEVIEW
_LISTINSTANCESRESPONSE.fields_by_name['instances'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2._INSTANCE
_CREATEINSTANCEREQUEST_LABELSENTRY.containing_type = _CREATEINSTANCEREQUEST
_CREATEINSTANCEREQUEST_METADATAENTRY.containing_type = _CREATEINSTANCEREQUEST
_CREATEINSTANCEREQUEST.fields_by_name['labels'].message_type = _CREATEINSTANCEREQUEST_LABELSENTRY
_CREATEINSTANCEREQUEST.fields_by_name['resources_spec'].message_type = _RESOURCESSPEC
_CREATEINSTANCEREQUEST.fields_by_name['metadata'].message_type = _CREATEINSTANCEREQUEST_METADATAENTRY
_CREATEINSTANCEREQUEST.fields_by_name['boot_disk_spec'].message_type = _ATTACHEDDISKSPEC
_CREATEINSTANCEREQUEST.fields_by_name['secondary_disk_specs'].message_type = _ATTACHEDDISKSPEC
_CREATEINSTANCEREQUEST.fields_by_name['network_interface_specs'].message_type = _NETWORKINTERFACESPEC
_UPDATEINSTANCEREQUEST_LABELSENTRY.containing_type = _UPDATEINSTANCEREQUEST
_UPDATEINSTANCEREQUEST_METADATAENTRY.containing_type = _UPDATEINSTANCEREQUEST
_UPDATEINSTANCEREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEINSTANCEREQUEST.fields_by_name['labels'].message_type = _UPDATEINSTANCEREQUEST_LABELSENTRY
_UPDATEINSTANCEREQUEST.fields_by_name['resources_spec'].message_type = _RESOURCESSPEC
_UPDATEINSTANCEREQUEST.fields_by_name['metadata'].message_type = _UPDATEINSTANCEREQUEST_METADATAENTRY
_ATTACHINSTANCEDISKREQUEST.fields_by_name['attached_disk_spec'].message_type = _ATTACHEDDISKSPEC
_DETACHINSTANCEDISKREQUEST.oneofs_by_name['disk'].fields.append(
  _DETACHINSTANCEDISKREQUEST.fields_by_name['disk_id'])
_DETACHINSTANCEDISKREQUEST.fields_by_name['disk_id'].containing_oneof = _DETACHINSTANCEDISKREQUEST.oneofs_by_name['disk']
_DETACHINSTANCEDISKREQUEST.oneofs_by_name['disk'].fields.append(
  _DETACHINSTANCEDISKREQUEST.fields_by_name['device_name'])
_DETACHINSTANCEDISKREQUEST.fields_by_name['device_name'].containing_oneof = _DETACHINSTANCEDISKREQUEST.oneofs_by_name['disk']
_LISTINSTANCEOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
_ATTACHEDDISKSPEC_DISKSPEC.containing_type = _ATTACHEDDISKSPEC
_ATTACHEDDISKSPEC_DISKSPEC.oneofs_by_name['source'].fields.append(
  _ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['image_id'])
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['image_id'].containing_oneof = _ATTACHEDDISKSPEC_DISKSPEC.oneofs_by_name['source']
_ATTACHEDDISKSPEC_DISKSPEC.oneofs_by_name['source'].fields.append(
  _ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['snapshot_id'])
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['snapshot_id'].containing_oneof = _ATTACHEDDISKSPEC_DISKSPEC.oneofs_by_name['source']
_ATTACHEDDISKSPEC.fields_by_name['mode'].enum_type = _ATTACHEDDISKSPEC_MODE
_ATTACHEDDISKSPEC.fields_by_name['disk_spec'].message_type = _ATTACHEDDISKSPEC_DISKSPEC
_ATTACHEDDISKSPEC_MODE.containing_type = _ATTACHEDDISKSPEC
_ATTACHEDDISKSPEC.oneofs_by_name['disk'].fields.append(
  _ATTACHEDDISKSPEC.fields_by_name['disk_spec'])
_ATTACHEDDISKSPEC.fields_by_name['disk_spec'].containing_oneof = _ATTACHEDDISKSPEC.oneofs_by_name['disk']
_ATTACHEDDISKSPEC.oneofs_by_name['disk'].fields.append(
  _ATTACHEDDISKSPEC.fields_by_name['disk_id'])
_ATTACHEDDISKSPEC.fields_by_name['disk_id'].containing_oneof = _ATTACHEDDISKSPEC.oneofs_by_name['disk']
_NETWORKINTERFACESPEC.fields_by_name['primary_v4_address_spec'].message_type = _PRIMARYADDRESSSPEC
_NETWORKINTERFACESPEC.fields_by_name['primary_v6_address_spec'].message_type = _PRIMARYADDRESSSPEC
_PRIMARYADDRESSSPEC.fields_by_name['one_to_one_nat_spec'].message_type = _ONETOONENATSPEC
_ONETOONENATSPEC.fields_by_name['ip_version'].enum_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2._IPVERSION
DESCRIPTOR.message_types_by_name['GetInstanceRequest'] = _GETINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['ListInstancesRequest'] = _LISTINSTANCESREQUEST
DESCRIPTOR.message_types_by_name['ListInstancesResponse'] = _LISTINSTANCESRESPONSE
DESCRIPTOR.message_types_by_name['CreateInstanceRequest'] = _CREATEINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['CreateInstanceMetadata'] = _CREATEINSTANCEMETADATA
DESCRIPTOR.message_types_by_name['UpdateInstanceRequest'] = _UPDATEINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['UpdateInstanceMetadata'] = _UPDATEINSTANCEMETADATA
DESCRIPTOR.message_types_by_name['DeleteInstanceRequest'] = _DELETEINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['DeleteInstanceMetadata'] = _DELETEINSTANCEMETADATA
DESCRIPTOR.message_types_by_name['GetInstanceSerialPortOutputRequest'] = _GETINSTANCESERIALPORTOUTPUTREQUEST
DESCRIPTOR.message_types_by_name['GetInstanceSerialPortOutputResponse'] = _GETINSTANCESERIALPORTOUTPUTRESPONSE
DESCRIPTOR.message_types_by_name['StopInstanceRequest'] = _STOPINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['StopInstanceMetadata'] = _STOPINSTANCEMETADATA
DESCRIPTOR.message_types_by_name['StartInstanceRequest'] = _STARTINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['StartInstanceMetadata'] = _STARTINSTANCEMETADATA
DESCRIPTOR.message_types_by_name['RestartInstanceRequest'] = _RESTARTINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['RestartInstanceMetadata'] = _RESTARTINSTANCEMETADATA
DESCRIPTOR.message_types_by_name['AttachInstanceDiskRequest'] = _ATTACHINSTANCEDISKREQUEST
DESCRIPTOR.message_types_by_name['AttachInstanceDiskMetadata'] = _ATTACHINSTANCEDISKMETADATA
DESCRIPTOR.message_types_by_name['DetachInstanceDiskRequest'] = _DETACHINSTANCEDISKREQUEST
DESCRIPTOR.message_types_by_name['DetachInstanceDiskMetadata'] = _DETACHINSTANCEDISKMETADATA
DESCRIPTOR.message_types_by_name['ListInstanceOperationsRequest'] = _LISTINSTANCEOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListInstanceOperationsResponse'] = _LISTINSTANCEOPERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['ResourcesSpec'] = _RESOURCESSPEC
DESCRIPTOR.message_types_by_name['AttachedDiskSpec'] = _ATTACHEDDISKSPEC
DESCRIPTOR.message_types_by_name['NetworkInterfaceSpec'] = _NETWORKINTERFACESPEC
DESCRIPTOR.message_types_by_name['PrimaryAddressSpec'] = _PRIMARYADDRESSSPEC
DESCRIPTOR.message_types_by_name['OneToOneNatSpec'] = _ONETOONENATSPEC
DESCRIPTOR.enum_types_by_name['InstanceView'] = _INSTANCEVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetInstanceRequest = _reflection.GeneratedProtocolMessageType('GetInstanceRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETINSTANCEREQUEST,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.GetInstanceRequest)
  ))
_sym_db.RegisterMessage(GetInstanceRequest)

ListInstancesRequest = _reflection.GeneratedProtocolMessageType('ListInstancesRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTINSTANCESREQUEST,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListInstancesRequest)
  ))
_sym_db.RegisterMessage(ListInstancesRequest)

ListInstancesResponse = _reflection.GeneratedProtocolMessageType('ListInstancesResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTINSTANCESRESPONSE,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListInstancesResponse)
  ))
_sym_db.RegisterMessage(ListInstancesResponse)

CreateInstanceRequest = _reflection.GeneratedProtocolMessageType('CreateInstanceRequest', (_message.Message,), dict(

  LabelsEntry = _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), dict(
    DESCRIPTOR = _CREATEINSTANCEREQUEST_LABELSENTRY,
    __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateInstanceRequest.LabelsEntry)
    ))
  ,

  MetadataEntry = _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), dict(
    DESCRIPTOR = _CREATEINSTANCEREQUEST_METADATAENTRY,
    __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateInstanceRequest.MetadataEntry)
    ))
  ,
  DESCRIPTOR = _CREATEINSTANCEREQUEST,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateInstanceRequest)
  ))
_sym_db.RegisterMessage(CreateInstanceRequest)
_sym_db.RegisterMessage(CreateInstanceRequest.LabelsEntry)
_sym_db.RegisterMessage(CreateInstanceRequest.MetadataEntry)

CreateInstanceMetadata = _reflection.GeneratedProtocolMessageType('CreateInstanceMetadata', (_message.Message,), dict(
  DESCRIPTOR = _CREATEINSTANCEMETADATA,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateInstanceMetadata)
  ))
_sym_db.RegisterMessage(CreateInstanceMetadata)

UpdateInstanceRequest = _reflection.GeneratedProtocolMessageType('UpdateInstanceRequest', (_message.Message,), dict(

  LabelsEntry = _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), dict(
    DESCRIPTOR = _UPDATEINSTANCEREQUEST_LABELSENTRY,
    __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateInstanceRequest.LabelsEntry)
    ))
  ,

  MetadataEntry = _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), dict(
    DESCRIPTOR = _UPDATEINSTANCEREQUEST_METADATAENTRY,
    __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateInstanceRequest.MetadataEntry)
    ))
  ,
  DESCRIPTOR = _UPDATEINSTANCEREQUEST,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateInstanceRequest)
  ))
_sym_db.RegisterMessage(UpdateInstanceRequest)
_sym_db.RegisterMessage(UpdateInstanceRequest.LabelsEntry)
_sym_db.RegisterMessage(UpdateInstanceRequest.MetadataEntry)

UpdateInstanceMetadata = _reflection.GeneratedProtocolMessageType('UpdateInstanceMetadata', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEINSTANCEMETADATA,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateInstanceMetadata)
  ))
_sym_db.RegisterMessage(UpdateInstanceMetadata)

DeleteInstanceRequest = _reflection.GeneratedProtocolMessageType('DeleteInstanceRequest', (_message.Message,), dict(
  DESCRIPTOR = _DELETEINSTANCEREQUEST,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DeleteInstanceRequest)
  ))
_sym_db.RegisterMessage(DeleteInstanceRequest)

DeleteInstanceMetadata = _reflection.GeneratedProtocolMessageType('DeleteInstanceMetadata', (_message.Message,), dict(
  DESCRIPTOR = _DELETEINSTANCEMETADATA,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DeleteInstanceMetadata)
  ))
_sym_db.RegisterMessage(DeleteInstanceMetadata)

GetInstanceSerialPortOutputRequest = _reflection.GeneratedProtocolMessageType('GetInstanceSerialPortOutputRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETINSTANCESERIALPORTOUTPUTREQUEST,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.GetInstanceSerialPortOutputRequest)
  ))
_sym_db.RegisterMessage(GetInstanceSerialPortOutputRequest)

GetInstanceSerialPortOutputResponse = _reflection.GeneratedProtocolMessageType('GetInstanceSerialPortOutputResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETINSTANCESERIALPORTOUTPUTRESPONSE,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.GetInstanceSerialPortOutputResponse)
  ))
_sym_db.RegisterMessage(GetInstanceSerialPortOutputResponse)

StopInstanceRequest = _reflection.GeneratedProtocolMessageType('StopInstanceRequest', (_message.Message,), dict(
  DESCRIPTOR = _STOPINSTANCEREQUEST,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.StopInstanceRequest)
  ))
_sym_db.RegisterMessage(StopInstanceRequest)

StopInstanceMetadata = _reflection.GeneratedProtocolMessageType('StopInstanceMetadata', (_message.Message,), dict(
  DESCRIPTOR = _STOPINSTANCEMETADATA,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.StopInstanceMetadata)
  ))
_sym_db.RegisterMessage(StopInstanceMetadata)

StartInstanceRequest = _reflection.GeneratedProtocolMessageType('StartInstanceRequest', (_message.Message,), dict(
  DESCRIPTOR = _STARTINSTANCEREQUEST,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.StartInstanceRequest)
  ))
_sym_db.RegisterMessage(StartInstanceRequest)

StartInstanceMetadata = _reflection.GeneratedProtocolMessageType('StartInstanceMetadata', (_message.Message,), dict(
  DESCRIPTOR = _STARTINSTANCEMETADATA,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.StartInstanceMetadata)
  ))
_sym_db.RegisterMessage(StartInstanceMetadata)

RestartInstanceRequest = _reflection.GeneratedProtocolMessageType('RestartInstanceRequest', (_message.Message,), dict(
  DESCRIPTOR = _RESTARTINSTANCEREQUEST,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.RestartInstanceRequest)
  ))
_sym_db.RegisterMessage(RestartInstanceRequest)

RestartInstanceMetadata = _reflection.GeneratedProtocolMessageType('RestartInstanceMetadata', (_message.Message,), dict(
  DESCRIPTOR = _RESTARTINSTANCEMETADATA,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.RestartInstanceMetadata)
  ))
_sym_db.RegisterMessage(RestartInstanceMetadata)

AttachInstanceDiskRequest = _reflection.GeneratedProtocolMessageType('AttachInstanceDiskRequest', (_message.Message,), dict(
  DESCRIPTOR = _ATTACHINSTANCEDISKREQUEST,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.AttachInstanceDiskRequest)
  ))
_sym_db.RegisterMessage(AttachInstanceDiskRequest)

AttachInstanceDiskMetadata = _reflection.GeneratedProtocolMessageType('AttachInstanceDiskMetadata', (_message.Message,), dict(
  DESCRIPTOR = _ATTACHINSTANCEDISKMETADATA,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.AttachInstanceDiskMetadata)
  ))
_sym_db.RegisterMessage(AttachInstanceDiskMetadata)

DetachInstanceDiskRequest = _reflection.GeneratedProtocolMessageType('DetachInstanceDiskRequest', (_message.Message,), dict(
  DESCRIPTOR = _DETACHINSTANCEDISKREQUEST,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DetachInstanceDiskRequest)
  ))
_sym_db.RegisterMessage(DetachInstanceDiskRequest)

DetachInstanceDiskMetadata = _reflection.GeneratedProtocolMessageType('DetachInstanceDiskMetadata', (_message.Message,), dict(
  DESCRIPTOR = _DETACHINSTANCEDISKMETADATA,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DetachInstanceDiskMetadata)
  ))
_sym_db.RegisterMessage(DetachInstanceDiskMetadata)

ListInstanceOperationsRequest = _reflection.GeneratedProtocolMessageType('ListInstanceOperationsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTINSTANCEOPERATIONSREQUEST,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListInstanceOperationsRequest)
  ))
_sym_db.RegisterMessage(ListInstanceOperationsRequest)

ListInstanceOperationsResponse = _reflection.GeneratedProtocolMessageType('ListInstanceOperationsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTINSTANCEOPERATIONSRESPONSE,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListInstanceOperationsResponse)
  ))
_sym_db.RegisterMessage(ListInstanceOperationsResponse)

ResourcesSpec = _reflection.GeneratedProtocolMessageType('ResourcesSpec', (_message.Message,), dict(
  DESCRIPTOR = _RESOURCESSPEC,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ResourcesSpec)
  ))
_sym_db.RegisterMessage(ResourcesSpec)

AttachedDiskSpec = _reflection.GeneratedProtocolMessageType('AttachedDiskSpec', (_message.Message,), dict(

  DiskSpec = _reflection.GeneratedProtocolMessageType('DiskSpec', (_message.Message,), dict(
    DESCRIPTOR = _ATTACHEDDISKSPEC_DISKSPEC,
    __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpec)
    ))
  ,
  DESCRIPTOR = _ATTACHEDDISKSPEC,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.AttachedDiskSpec)
  ))
_sym_db.RegisterMessage(AttachedDiskSpec)
_sym_db.RegisterMessage(AttachedDiskSpec.DiskSpec)

NetworkInterfaceSpec = _reflection.GeneratedProtocolMessageType('NetworkInterfaceSpec', (_message.Message,), dict(
  DESCRIPTOR = _NETWORKINTERFACESPEC,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.NetworkInterfaceSpec)
  ))
_sym_db.RegisterMessage(NetworkInterfaceSpec)

PrimaryAddressSpec = _reflection.GeneratedProtocolMessageType('PrimaryAddressSpec', (_message.Message,), dict(
  DESCRIPTOR = _PRIMARYADDRESSSPEC,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.PrimaryAddressSpec)
  ))
_sym_db.RegisterMessage(PrimaryAddressSpec)

OneToOneNatSpec = _reflection.GeneratedProtocolMessageType('OneToOneNatSpec', (_message.Message,), dict(
  DESCRIPTOR = _ONETOONENATSPEC,
  __module__ = 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.OneToOneNatSpec)
  ))
_sym_db.RegisterMessage(OneToOneNatSpec)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'))
_GETINSTANCEREQUEST.fields_by_name['instance_id'].has_options = True
_GETINSTANCEREQUEST.fields_by_name['instance_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50'))
_LISTINSTANCESREQUEST.fields_by_name['folder_id'].has_options = True
_LISTINSTANCESREQUEST.fields_by_name['folder_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50'))
_LISTINSTANCESREQUEST.fields_by_name['page_size'].has_options = True
_LISTINSTANCESREQUEST.fields_by_name['page_size']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\372\3071\006<=1000'))
_LISTINSTANCESREQUEST.fields_by_name['page_token'].has_options = True
_LISTINSTANCESREQUEST.fields_by_name['page_token']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\005<=100'))
_LISTINSTANCESREQUEST.fields_by_name['filter'].has_options = True
_LISTINSTANCESREQUEST.fields_by_name['filter']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\006<=1000'))
_CREATEINSTANCEREQUEST_LABELSENTRY.has_options = True
_CREATEINSTANCEREQUEST_LABELSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_CREATEINSTANCEREQUEST_METADATAENTRY.has_options = True
_CREATEINSTANCEREQUEST_METADATAENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_CREATEINSTANCEREQUEST.fields_by_name['folder_id'].has_options = True
_CREATEINSTANCEREQUEST.fields_by_name['folder_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50'))
_CREATEINSTANCEREQUEST.fields_by_name['name'].has_options = True
_CREATEINSTANCEREQUEST.fields_by_name['name']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'))
_CREATEINSTANCEREQUEST.fields_by_name['description'].has_options = True
_CREATEINSTANCEREQUEST.fields_by_name['description']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\005<=256'))
_CREATEINSTANCEREQUEST.fields_by_name['labels'].has_options = True
_CREATEINSTANCEREQUEST.fields_by_name['labels']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*'))
_CREATEINSTANCEREQUEST.fields_by_name['zone_id'].has_options = True
_CREATEINSTANCEREQUEST.fields_by_name['zone_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50'))
_CREATEINSTANCEREQUEST.fields_by_name['platform_id'].has_options = True
_CREATEINSTANCEREQUEST.fields_by_name['platform_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\362\3071\013standard-v1'))
_CREATEINSTANCEREQUEST.fields_by_name['resources_spec'].has_options = True
_CREATEINSTANCEREQUEST.fields_by_name['resources_spec']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001'))
_CREATEINSTANCEREQUEST.fields_by_name['boot_disk_spec'].has_options = True
_CREATEINSTANCEREQUEST.fields_by_name['boot_disk_spec']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001'))
_CREATEINSTANCEREQUEST.fields_by_name['secondary_disk_specs'].has_options = True
_CREATEINSTANCEREQUEST.fields_by_name['secondary_disk_specs']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\202\3101\003<=3'))
_CREATEINSTANCEREQUEST.fields_by_name['network_interface_specs'].has_options = True
_CREATEINSTANCEREQUEST.fields_by_name['network_interface_specs']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\202\3101\0011'))
_CREATEINSTANCEREQUEST.fields_by_name['hostname'].has_options = True
_CREATEINSTANCEREQUEST.fields_by_name['hostname']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'))
_CREATEINSTANCEMETADATA.fields_by_name['instance_id'].has_options = True
_CREATEINSTANCEMETADATA.fields_by_name['instance_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\004<=50'))
_UPDATEINSTANCEREQUEST_LABELSENTRY.has_options = True
_UPDATEINSTANCEREQUEST_LABELSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_UPDATEINSTANCEREQUEST_METADATAENTRY.has_options = True
_UPDATEINSTANCEREQUEST_METADATAENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_UPDATEINSTANCEREQUEST.fields_by_name['instance_id'].has_options = True
_UPDATEINSTANCEREQUEST.fields_by_name['instance_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50'))
_UPDATEINSTANCEREQUEST.fields_by_name['name'].has_options = True
_UPDATEINSTANCEREQUEST.fields_by_name['name']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'))
_UPDATEINSTANCEREQUEST.fields_by_name['description'].has_options = True
_UPDATEINSTANCEREQUEST.fields_by_name['description']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\005<=256'))
_UPDATEINSTANCEREQUEST.fields_by_name['labels'].has_options = True
_UPDATEINSTANCEREQUEST.fields_by_name['labels']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\202\3101\004<=64\212\3101\004<=63\362\3071\013[-_0-9a-z]*\262\3101\006\032\0041-63\262\3101\022\022\020[a-z][-_0-9a-z]*'))
_UPDATEINSTANCEREQUEST.fields_by_name['platform_id'].has_options = True
_UPDATEINSTANCEREQUEST.fields_by_name['platform_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\3071\013standard-v1'))
_DELETEINSTANCEREQUEST.fields_by_name['instance_id'].has_options = True
_DELETEINSTANCEREQUEST.fields_by_name['instance_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50'))
_GETINSTANCESERIALPORTOUTPUTREQUEST.fields_by_name['instance_id'].has_options = True
_GETINSTANCESERIALPORTOUTPUTREQUEST.fields_by_name['instance_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50'))
_STOPINSTANCEREQUEST.fields_by_name['instance_id'].has_options = True
_STOPINSTANCEREQUEST.fields_by_name['instance_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50'))
_STARTINSTANCEREQUEST.fields_by_name['instance_id'].has_options = True
_STARTINSTANCEREQUEST.fields_by_name['instance_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50'))
_RESTARTINSTANCEREQUEST.fields_by_name['instance_id'].has_options = True
_RESTARTINSTANCEREQUEST.fields_by_name['instance_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50'))
_ATTACHINSTANCEDISKREQUEST.fields_by_name['instance_id'].has_options = True
_ATTACHINSTANCEDISKREQUEST.fields_by_name['instance_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50'))
_ATTACHINSTANCEDISKREQUEST.fields_by_name['attached_disk_spec'].has_options = True
_ATTACHINSTANCEDISKREQUEST.fields_by_name['attached_disk_spec']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001'))
_DETACHINSTANCEDISKREQUEST.oneofs_by_name['disk'].has_options = True
_DETACHINSTANCEDISKREQUEST.oneofs_by_name['disk']._options = _descriptor._ParseOptions(descriptor_pb2.OneofOptions(), _b('\300\3011\001'))
_DETACHINSTANCEDISKREQUEST.fields_by_name['instance_id'].has_options = True
_DETACHINSTANCEDISKREQUEST.fields_by_name['instance_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50'))
_DETACHINSTANCEDISKREQUEST.fields_by_name['disk_id'].has_options = True
_DETACHINSTANCEDISKREQUEST.fields_by_name['disk_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\004<=50'))
_DETACHINSTANCEDISKREQUEST.fields_by_name['device_name'].has_options = True
_DETACHINSTANCEDISKREQUEST.fields_by_name['device_name']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\3071\024[a-z][a-z0-9-_]{,19}'))
_LISTINSTANCEOPERATIONSREQUEST.fields_by_name['instance_id'].has_options = True
_LISTINSTANCEOPERATIONSREQUEST.fields_by_name['instance_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50'))
_LISTINSTANCEOPERATIONSREQUEST.fields_by_name['page_size'].has_options = True
_LISTINSTANCEOPERATIONSREQUEST.fields_by_name['page_size']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\372\3071\006<=1000'))
_LISTINSTANCEOPERATIONSREQUEST.fields_by_name['page_token'].has_options = True
_LISTINSTANCEOPERATIONSREQUEST.fields_by_name['page_token']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\005<=100'))
_RESOURCESSPEC.fields_by_name['memory'].has_options = True
_RESOURCESSPEC.fields_by_name['memory']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\372\3071\r<=34359738368'))
_RESOURCESSPEC.fields_by_name['cores'].has_options = True
_RESOURCESSPEC.fields_by_name['cores']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\372\3071\004<=32'))
_RESOURCESSPEC.fields_by_name['core_fraction'].has_options = True
_RESOURCESSPEC.fields_by_name['core_fraction']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\372\3071\0070,5,100'))
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['name'].has_options = True
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['name']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'))
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['description'].has_options = True
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['description']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\005<=256'))
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['type_id'].has_options = True
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['type_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\004<=50'))
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['size'].has_options = True
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['size']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\372\3071\0254194304-4398046511104'))
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['image_id'].has_options = True
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['image_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\004<=50'))
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['snapshot_id'].has_options = True
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['snapshot_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\004<=50'))
_ATTACHEDDISKSPEC.oneofs_by_name['disk'].has_options = True
_ATTACHEDDISKSPEC.oneofs_by_name['disk']._options = _descriptor._ParseOptions(descriptor_pb2.OneofOptions(), _b('\300\3011\001'))
_ATTACHEDDISKSPEC.fields_by_name['device_name'].has_options = True
_ATTACHEDDISKSPEC.fields_by_name['device_name']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\362\3071\024[a-z][a-z0-9-_]{,19}'))
_ATTACHEDDISKSPEC.fields_by_name['disk_id'].has_options = True
_ATTACHEDDISKSPEC.fields_by_name['disk_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\212\3101\004<=50'))
_NETWORKINTERFACESPEC.fields_by_name['subnet_id'].has_options = True
_NETWORKINTERFACESPEC.fields_by_name['subnet_id']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\004<=50'))
_ONETOONENATSPEC.fields_by_name['ip_version'].has_options = True
_ONETOONENATSPEC.fields_by_name['ip_version']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001'))

_INSTANCESERVICE = _descriptor.ServiceDescriptor(
  name='InstanceService',
  full_name='yandex.cloud.compute.v1.InstanceService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=4616,
  serialized_end=6823,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.compute.v1.InstanceService.Get',
    index=0,
    containing_service=None,
    input_type=_GETINSTANCEREQUEST,
    output_type=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2._INSTANCE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002%\022#/compute/v1/instances/{instance_id}')),
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.compute.v1.InstanceService.List',
    index=1,
    containing_service=None,
    input_type=_LISTINSTANCESREQUEST,
    output_type=_LISTINSTANCESRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\027\022\025/compute/v1/instances')),
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.compute.v1.InstanceService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEINSTANCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\032\"\025/compute/v1/instances:\001*\262\322*\"\n\026CreateInstanceMetadata\022\010Instance')),
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.compute.v1.InstanceService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEINSTANCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002(2#/compute/v1/instances/{instance_id}:\001*\262\322*\"\n\026UpdateInstanceMetadata\022\010Instance')),
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.compute.v1.InstanceService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEINSTANCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002%*#/compute/v1/instances/{instance_id}\262\322*/\n\026DeleteInstanceMetadata\022\025google.protobuf.Empty')),
  ),
  _descriptor.MethodDescriptor(
    name='GetSerialPortOutput',
    full_name='yandex.cloud.compute.v1.InstanceService.GetSerialPortOutput',
    index=5,
    containing_service=None,
    input_type=_GETINSTANCESERIALPORTOUTPUTREQUEST,
    output_type=_GETINSTANCESERIALPORTOUTPUTRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0026\0224/compute/v1/instances/{instance_id}:serialPortOutput')),
  ),
  _descriptor.MethodDescriptor(
    name='Stop',
    full_name='yandex.cloud.compute.v1.InstanceService.Stop',
    index=6,
    containing_service=None,
    input_type=_STOPINSTANCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002*\"(/compute/v1/instances/{instance_id}:stop\262\322*-\n\024StopInstanceMetadata\022\025google.protobuf.Empty')),
  ),
  _descriptor.MethodDescriptor(
    name='Start',
    full_name='yandex.cloud.compute.v1.InstanceService.Start',
    index=7,
    containing_service=None,
    input_type=_STARTINSTANCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002+\")/compute/v1/instances/{instance_id}:start\262\322*.\n\025StartInstanceMetadata\022\025google.protobuf.Empty')),
  ),
  _descriptor.MethodDescriptor(
    name='Restart',
    full_name='yandex.cloud.compute.v1.InstanceService.Restart',
    index=8,
    containing_service=None,
    input_type=_RESTARTINSTANCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002-\"+/compute/v1/instances/{instance_id}:restart\262\322*0\n\027RestartInstanceMetadata\022\025google.protobuf.Empty')),
  ),
  _descriptor.MethodDescriptor(
    name='AttachDisk',
    full_name='yandex.cloud.compute.v1.InstanceService.AttachDisk',
    index=9,
    containing_service=None,
    input_type=_ATTACHINSTANCEDISKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0023\"./compute/v1/instances/{instance_id}:attachDisk:\001*\262\322*&\n\032AttachInstanceDiskMetadata\022\010Instance')),
  ),
  _descriptor.MethodDescriptor(
    name='DetachDisk',
    full_name='yandex.cloud.compute.v1.InstanceService.DetachDisk',
    index=10,
    containing_service=None,
    input_type=_DETACHINSTANCEDISKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0023\"./compute/v1/instances/{instance_id}:detachDisk:\001*\262\322*&\n\032DetachInstanceDiskMetadata\022\010Instance')),
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.compute.v1.InstanceService.ListOperations',
    index=11,
    containing_service=None,
    input_type=_LISTINSTANCEOPERATIONSREQUEST,
    output_type=_LISTINSTANCEOPERATIONSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0020\022./compute/v1/instances/{instance_id}/operations')),
  ),
])
_sym_db.RegisterServiceDescriptor(_INSTANCESERVICE)

DESCRIPTOR.services_by_name['InstanceService'] = _INSTANCESERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/clickhouse/v1/database.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/clickhouse/v1/database.proto',
  package='yandex.cloud.mdb.clickhouse.v1',
  syntax='proto3',
  serialized_pb=_b('\n-yandex/cloud/mdb/clickhouse/v1/database.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\x1a\x1dyandex/cloud/validation.proto\",\n\x08\x44\x61tabase\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\";\n\x0c\x44\x61tabaseSpec\x12+\n\x04name\x18\x01 \x01(\tB\x1d\xe8\xc7\x31\x01\x8a\xc8\x31\x04\x31-63\xf2\xc7\x31\r[a-zA-Z0-9_]+BOZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3')
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_DATABASE = _descriptor.Descriptor(
  name='Database',
  full_name='yandex.cloud.mdb.clickhouse.v1.Database',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.clickhouse.v1.Database.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.clickhouse.v1.Database.cluster_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=156,
)


_DATABASESPEC = _descriptor.Descriptor(
  name='DatabaseSpec',
  full_name='yandex.cloud.mdb.clickhouse.v1.DatabaseSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.clickhouse.v1.DatabaseSpec.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\0041-63\362\3071\r[a-zA-Z0-9_]+')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=158,
  serialized_end=217,
)

DESCRIPTOR.message_types_by_name['Database'] = _DATABASE
DESCRIPTOR.message_types_by_name['DatabaseSpec'] = _DATABASESPEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Database = _reflection.GeneratedProtocolMessageType('Database', (_message.Message,), dict(
  DESCRIPTOR = _DATABASE,
  __module__ = 'yandex.cloud.mdb.clickhouse.v1.database_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.Database)
  ))
_sym_db.RegisterMessage(Database)

DatabaseSpec = _reflection.GeneratedProtocolMessageType('DatabaseSpec', (_message.Message,), dict(
  DESCRIPTOR = _DATABASESPEC,
  __module__ = 'yandex.cloud.mdb.clickhouse.v1.database_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.clickhouse.v1.DatabaseSpec)
  ))
_sym_db.RegisterMessage(DatabaseSpec)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse'))
_DATABASESPEC.fields_by_name['name'].has_options = True
_DATABASESPEC.fields_by_name['name']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\350\3071\001\212\3101\0041-63\362\3071\r[a-zA-Z0-9_]+'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/api/operation.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/api/operation.proto',
  package='yandex.api',
  syntax='proto3',
  serialized_pb=_b('\n\x1ayandex/api/operation.proto\x12\nyandex.api\x1a google/protobuf/descriptor.proto\"/\n\tOperation\x12\x10\n\x08metadata\x18\x01 \x01(\t\x12\x10\n\x08response\x18\x02 \x01(\t:J\n\toperation\x12\x1e.google.protobuf.MethodOptions\x18\xa6\xaa\x05 \x01(\x0b\x32\x15.yandex.api.OperationB4Z2github.com/yandex-cloud/go-genproto/yandex/api;apib\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])


OPERATION_FIELD_NUMBER = 87334
operation = _descriptor.FieldDescriptor(
  name='operation', full_name='yandex.api.operation', index=0,
  number=87334, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  options=None, file=DESCRIPTOR)


_OPERATION = _descriptor.Descriptor(
  name='Operation',
  full_name='yandex.api.Operation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='yandex.api.Operation.metadata', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response', full_name='yandex.api.Operation.response', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=76,
  serialized_end=123,
)

DESCRIPTOR.message_types_by_name['Operation'] = _OPERATION
DESCRIPTOR.extensions_by_name['operation'] = operation
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Operation = _reflection.GeneratedProtocolMessageType('Operation', (_message.Message,), dict(
  DESCRIPTOR = _OPERATION,
  __module__ = 'yandex.api.operation_pb2'
  # @@protoc_insertion_point(class_scope:yandex.api.Operation)
  ))
_sym_db.RegisterMessage(Operation)

operation.message_type = _OPERATION
google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(operation)

DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z2github.com/yandex-cloud/go-genproto/yandex/api;api'))
# @@protoc_insertion_point(module_scope)



import time
from datetime import datetime

# jwt package depends on cryptography
import cryptography
import jwt


from yandex.cloud.iam.v1.iam_token_service_pb2 import CreateIamTokenRequest


def __validate_service_account_key(sa_key):
    if not isinstance(sa_key, dict):
        raise RuntimeError("Invalid Service Account Key: expecting dictionary, actually got {}".format(type(sa_key)))

    obj_id = sa_key.get("id")
    sa_id = sa_key.get("service_account_id")
    private_key = sa_key.get("private_key")

    if not obj_id:
        raise RuntimeError("Invalid Service Account Key: missing key object id.")

    if not sa_id:
        raise RuntimeError("Invalid Service Account Key: missing service account id.")

    if not private_key:
        raise RuntimeError("Invalid Service Account Key: missing private key.")


def get_auth_token_request_func(token=None, service_account_key=None):
    if token and service_account_key:
        raise RuntimeError("Conflicting API credentials properties 'token' and 'service-account-key' are set.")

    if token:
        return TokenAuth(token=token).get_token_request

    if service_account_key is None:
        raise RuntimeError("Please provide API credentials, non empty 'token' or 'service-account-key'")

    __validate_service_account_key(service_account_key)
    return ServiceAccountAuth(service_account_key).get_token_request


class TokenAuth:
    def __init__(self, token):
        self.__oauth_token = token

    def get_token_request(self):
        return CreateIamTokenRequest(yandex_passport_oauth_token=self.__oauth_token)


class ServiceAccountAuth:
    __SECONDS_IN_HOUR = 60. * 60.

    def __init__(self, sa_key):
        self.__sa_key = sa_key

    def get_token_request(self):
        return CreateIamTokenRequest(jwt=self.__prepare_request())

    def __prepare_request(self):
        now = time.time()
        now_utc = datetime.utcfromtimestamp(now)
        exp_utc = datetime.utcfromtimestamp(now + self.__SECONDS_IN_HOUR)
        payload = {
            "iss": self.__sa_key["service_account_id"],
            "aud": "https://iam.api.cloud.yandex.net/iam/v1/tokens",
            "iat": now_utc,
            "exp": exp_utc,
        }

        headers = {
            "typ": "JWT",
            "alg": "PS256",
            "kid": self.__sa_key["id"],
        }

        return jwt.encode(payload, self.__sa_key["private_key"], algorithm="PS256", headers=headers)
